@@ -54,6 +54,12 @@ def random_alloy(
             )
         )
 
+    elif max_elements == min_elements:
+        if max_elements == len(list(percentage_constraints.keys())):
+            elements = list(percentage_constraints.keys())
+        elif max_elements == len(allowed_elements):
+            elements = allowed_elements[:]
+
     else:
         elements = list(
             np.random.choice(
@@ -80,6 +86,7 @@ def random_alloy(
             "percentage_step": percentage_step,
             "min_elements": min_elements,
             "max_elements": max_elements,
+            "allowed_elements": allowed_elements,
         },
     )
 
@@ -155,6 +162,7 @@ def mixture(alloys: List[mg.Alloy], weights: Optional[list] = None):
                     "percentages": {},
                     "min_elements": 1,
                     "max_elements": 1,
+                    "percentage_step": 0.01,
                 }
 
             if "min_elements" in alloy.constraints:
@@ -167,6 +175,11 @@ def mixture(alloys: List[mg.Alloy], weights: Optional[list] = None):
                     constraints["max_elements"],
                     alloy.constraints["max_elements"],
                 )
+            if "percentage_step" in alloy.constraints:
+                constraints["percentage_step"] = min(
+                    constraints["percentage_step"],
+                    alloy.constraints["percentage_step"],
+                )
 
             if "percentages" in alloy.constraints:
                 for element in alloy.constraints["percentages"]:
@@ -203,6 +216,31 @@ def mixture(alloys: List[mg.Alloy], weights: Optional[list] = None):
                                 ],
                             )
 
+                    if (
+                        "precedence"
+                        in alloy.constraints["percentages"][element]
+                    ):
+                        if (
+                            "precedence"
+                            not in constraints["percentages"][element]
+                        ):
+                            constraints["percentages"][element][
+                                "precedence"
+                            ] = alloy.constraints["percentages"][element][
+                                "precedence"
+                            ]
+                        else:
+                            constraints["percentages"][element][
+                                "precedence"
+                            ] = max(
+                                constraints["percentages"][element][
+                                    "precedence"
+                                ],
+                                alloy.constraints["percentages"][element][
+                                    "precedence"
+                                ],
+                            )
+
     if weights is None:
         weights = [1.0 / len(alloys)] * len(alloys)
 
